DECLARE
  cnt integer;
BEGIN
  SELECT count(*) INTO cnt 
    FROM user_tables WHERE lower(table_name)='layers_recordlinks';
  IF cnt=0  THEN
  
    EXECUTE IMMEDIATE 'CREATE TABLE Layers_RecordLinks
(
  ID NUMBER(10,0) NOT NULL,
  LeftID NUMBER(10,0) NOT NULL,
  LeftLayer NUMBER(10,0) NOT NULL,
  LeftVersion NUMBER(10,0),
  RightID NUMBER(10,0) NOT NULL,
  RightLayer NUMBER(10,0) NOT NULL,
  RightVersion NUMBER(10,0),
  LinkType NUMBER(5,0) DEFAULT 0,
  CREATEDATE DATE NOT NULL, 
  CREATERUSER VARCHAR2(30) NOT NULL,
  
   CHECK ((ID<=2147483647)AND(ID>-2147483648)) ENABLE, 
	 CHECK ((LeftID<=2147483647)AND(LeftID>-2147483648)) ENABLE, 
	 CHECK ((LeftLayer<=2147483647)AND(LeftLayer>-2147483648)) ENABLE, 
	 CHECK ((LeftVersion<=2147483647)AND(LeftVersion>-2147483648)) ENABLE, 
   CHECK ((RightID<=2147483647)AND(RightID>-2147483648)) ENABLE, 
	 CHECK ((RightLayer<=2147483647)AND(RightLayer>-2147483648)) ENABLE, 
	 CHECK ((RightVersion<=2147483647)AND(RightVersion>-2147483648)) ENABLE, 
  
   CONSTRAINT "PK_L_RL" PRIMARY KEY ("ID")
)';
    EXECUTE IMMEDIATE 'CREATE INDEX IDX_L_RL_ID1 ON Layers_RecordLinks(LeftID)';
    EXECUTE IMMEDIATE 'CREATE INDEX IDX_L_RL_ID2 ON Layers_RecordLinks(RightID)';
    EXECUTE IMMEDIATE 'CREATE INDEX IDX_L_RL_LAYER1 ON Layers_RecordLinks(LeftLayer,LeftVersion)';
    EXECUTE IMMEDIATE 'CREATE INDEX IDX_L_RL_LAYER2 ON Layers_RecordLinks(RightLayer,RightVersion)';
    EXECUTE IMMEDIATE 'CREATE INDEX IDX_L_RL_LINKTYPE ON Layers_RecordLinks(LinkType)';
    
    EXECUTE IMMEDIATE 'GRANT ALL ON Layers_RecordLinks TO PUBLIC';

  END IF;
  
END;
/


CREATE OR REPLACE TRIGGER "TR_L_RL_BI" 
 BEFORE
  INSERT
 ON Layers_RecordLinks
REFERENCING NEW AS NEW OLD AS OLD
 FOR EACH ROW
begin
  if (:new.id is null) then select G_SHARED.nextval into :new.Id from DUAL; end if;
  :NEW.CreateDate := SYSDATE;
  :NEW.CreaterUser := USER;
end;
/

CREATE OR REPLACE TRIGGER TR_L_RL_BU
  BEFORE UPDATE
  ON Layers_RecordLinks
  FOR EACH ROW
begin
  raise_application_error(-20503,'Modifying record links is prohibited');
end;
/
